use strict;
use warnings;

package MyApp::Controller::Deep;

use base 'WebNano::Controller';

sub search_subcontrollers { 1 }

1;
